@@ -1,6 +1,6 @@
 ;;; examples/nyacc/lang/c99/ffi-help.scm
 
-;; Copyright (C) 2016-2020 Matthew R. Wette
+;; Copyright (C) 2016-2021 Matthew R. Wette
 ;;
 ;; This library is free software; you can redistribute it and/or
 ;; modify it under the terms of the GNU Lesser General Public
@@ -57,13 +57,15 @@
 	    define-ffi-module
 	    compile-ffi-file
 	    load-include-file
-	    fh-cnvt-udecl fh-cnvt-cdecl fh-cnvt-cdecl-str fh-scm-str->scm-exp
+	    fh-cnvt-udecl fh-cnvt-cdecl fh-cnvt-cdecl->str fh-scm-str->scm-exp
 	    string-member-proc string-renamer
 	    ;;
-	    C-fun-decl->scm
+	    C-decl->scm C-decl fh-llibs
 	    ;;pkg-config-incs pkg-config-defs pkg-config-libs
-	    ;; debugging
-	    ;;ffi-symmap
+
+	    ;;ffi-symmap  		; <= debugging
+
+	    C-fun-decl->scm		; deprecated
 	    )
   #:use-module (nyacc lang c99 cpp)
   #:use-module (nyacc lang c99 parser)
@@ -92,7 +94,7 @@
   #:use-module (ice-9 regex)
   #:use-module (ice-9 pretty-print)
   #:re-export (*nyacc-version*)
-  #:version (1 04 0))
+  #:version (1 05 0))
 
 (define fh-cpp-defs
   (cond
@@ -834,7 +836,7 @@
 			    (udecl (udecl-rem-type-qual udecl))
 			    (mdecl (udecl->mdecl udecl)))
 		       (mtail->ffi-desc (cdr mdecl) #t)))
-		   (clean-fields fields))))
+		   (clean-and-unitize-fields fields))))
     (((struct-def (ident ,name) ,field-list))
      (mtail->ffi-desc `((struct-def ,field-list))))
     
@@ -1925,7 +1927,8 @@
 			     #:return-defs #t
 			     #:show-incs (*show-incs*)
 			     #:debug (*debug-parse*)))
-	      (lambda (tree defs) (*ddict* defs) tree))))
+	      (lambda (tree defs)
+		(*ddict* defs) tree))))
 	(fherr "parse failed"))))
 
 ;; @deffn parse-includes attrs
@@ -1996,6 +1999,7 @@
 	 ;;
 	 (tree (begin
 		 (if (memq 'parse dbugl) (*debug-parse* #t))
+		 (and (assq-ref script-options 'show-incs) (*show-incs* #t))
 		 (cond
 		  ((assq-ref attrs 'include) (parse-includes attrs))
 		  ((assq-ref attrs 'api-code) =>
@@ -2025,9 +2029,6 @@
 	       (append var seed)))
 	   '() ext-mods)))
 
-    ;;(sferr "ffi-decls:\n") (pperr ffi-decls)
-    ;;(sferr "QUIT\n") (quit)
-
     ;; set globals
     (*prefix* (m-path->name path))
     (*udict* udict)
@@ -2075,7 +2076,9 @@
 
 ;; === test compiler ================
 
-;; @deffn {Procedure} C-fun-decl->scm code
+(define fh-llibs (delay '()))
+
+;; @deffn {Procedure} C-decl->scm code-string => sexp
 ;; Generate a symbolic expression that evals to a Guile procedure.
 ;; @example
 ;; (define fmod-exp (C-fun-decl->proc "double dmod(double, double);"))
@@ -2083,15 +2086,20 @@
 ;; (fmod 2.3 0.5)
 ;; @end example
 ;; @end deffn
-(define (C-fun-decl->scm code)
+(define* (C-decl->scm code #:key expand)
   (let ((tree (with-input-from-string code parse-c99)))
-    (if tree
-	(let* ((udict (unitize-decl (sx-ref tree 1)))
-	       (name (caar udict)) (udecl (cdar udict))
-	       (gen1 (fh-cnvt-udecl udecl '()))
-	       (gen2 (with-input-from-string gen1 read))
-	       (gen3 (caddr gen2)))
-	  gen3))))
+    (and tree
+	 (let* ((udict (c99-trans-unit->udict tree))
+		(udecl (cdr (last udict)))
+		(udecl (if expand (expand-typerefs udecl udict) udecl))
+		(str-decl (fh-cnvt-udecl udecl udict)) 
+		(scm-decl (with-input-from-string str-decl read))
+		(scm-value (sx-ref scm-decl 2)))
+	   scm-value))))
+(define C-fun-decl->scm C-decl->scm)
+
+(define-syntax-rule (C-decl c-code-string)
+  (eval (C-decl->scm c-code-string) (current-module)))
 
 (define* (fh-cnvt-udecl udecl udict #:key (prefix "fh"))
   (parameterize ((*options* '()) (*wrapped* '()) (*defined* '())
@@ -2132,7 +2140,7 @@
 			     
 ;; === repl compiler ================
 
-;; @deffn {Procedure} load-include-file filename [pkg-config]
+;; @deffn {Procedure} load-include-file filename [#pkg-config pkg]
 ;; This is the functionality that Ludo was asking for: to be at guile
 ;; prompt and be able to issue
 ;; @example
@@ -2144,13 +2152,17 @@
 ;;   our code generates strings and not lists.
 ;; + and=> with-output-to-string  eval
 ;; + first need to cut up intro-ffi
-
 ;; options:
 ;;   api-code cpp-defs decl-filter
 ;;   inc-dirs inc-filter inc-help include
 ;;   library pkg-config renamer
 (define* (load-include-file filename
 			    #:key pkg-config)
+  "- Procedure: load-include-file filename [#:pkg-config pkg]
+     This is the functionality that Ludo was asking for: to be at guile
+     prompt and be able to issue
+          (use-modules (nyacc lang c99 ffi-help))
+          (load-include-file \"cairo.h\" #:pkg-config \"cairo\")"
   (parameterize ((*options* '()) (*wrapped* '()) (*defined* '())
 		 (*renamer* identity) (*errmsgs* '())
 		 (*prefix* "") (*mport* #t) (*udict* '()))
