@@ -59,9 +59,9 @@
   #:use-module (rnrs bytevectors)
   #:use-module ((system foreign) #:prefix ffi:)
   #:use-module (srfi srfi-9)
-  #:version (1 04 0))
+  #:version (1 05 0))
 
-(define *ffi-help-version* "1.04.0")
+(define *ffi-help-version* "1.05.0")
 
 (define (sferr fmt . args) (apply simple-format (current-error-port) fmt args))
 
@@ -321,7 +321,8 @@
     (define type
       (make-fht (quote type)
 		(lambda (obj)
-		  (bytestructure-bytevector (struct-ref obj 0)))
+		  (ffi:bytevector->pointer
+		   (bytestructure-bytevector (struct-ref obj 0))))
 		(lambda (val)
 		  (make-struct/no-tail type (bytestructure desc val)))
 		#f #f
